@@ -15,6 +15,9 @@ TR_C_START
 
 typedef TessBaseAPIExt* TessH;
 
+struct ConfidenceNode;
+struct ResultNode;
+
 TESSERWRAP_CAPI TessH Tesserwrap_Init(const char *datadir, const char *lang);
 TESSERWRAP_CAPI void Tesserwrap_Destroy(TessH tesserwrap);
 TESSERWRAP_CAPI void Tesserwrap_GetRectangle(TessH tesserwrap,
@@ -31,5 +34,8 @@ TESSERWRAP_CAPI tesseract::PageSegMode Tesserwrap_GetPageSegMode(TessH tesserwra
 TESSERWRAP_CAPI const char *Tesserwrap_GetUTF8Text(TessH tesserwrap);
 TESSERWRAP_CAPI void Tesserwrap_Clear(TessH tesserwrap);
 TESSERWRAP_CAPI void Tesserwrap_SetVariable(TessH tesserwrap, const char *key, const char *value);
+TESSERWRAP_CAPI int Tesserwrap_MeanTextConf(TessH tesserwrap);
+TESSERWRAP_CAPI ConfidenceNode *Tesserwrap_AllWordConfidences(TessH tesserwrap);
+TESSERWRAP_CAPI ResultNode *Tesserwrap_GetResult(TessH tesserwrap , int level);
 
 TR_C_END
